cmd

package
v0.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2026 License: Apache-2.0 Imports: 32 Imported by: 0

Documentation

Overview

Package cmd provides the command-line interface for kubectl-coco.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Execute runs the root command

Types

This section is empty.

Directories

Path Synopsis
Package initdata provides the initdata subcommand group for cococtl.
Package initdata provides the initdata subcommand group for cococtl.
Package kbs provides the kbs subcommand group for cococtl.
Package kbs provides the kbs subcommand group for cococtl.

Jump to